==> config-api-0.3.11-sources.jar: org/wildfly/swarm/config/undertow/configuration/CustomFilter.java <==
package org.wildfly.swarm.config.undertow.configuration;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * Custom filter
 */
@ResourceType("custom-filter")
public class CustomFilter<T extends CustomFilter> {

	private String key;
	private String className;
	private String module;
	private Map parameters = new java.util.HashMap<String, Object>();

	public CustomFilter(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Class name of HttpHandler
	 */
	@ModelNodeBinding(detypedName = "class-name")
	public String className() {
		return this.className;
	}

	/**
	 * Class name of HttpHandler
	 */
	@SuppressWarnings("unchecked")
	public CustomFilter className(String value) {
		this.className = value;
		return (CustomFilter) this;
	}

	/**
	 * Module name where class can be loaded from
	 */
	@ModelNodeBinding(detypedName = "module")
	public String module() {
		return this.module;
	}

	/**
	 * Module name where class can be loaded from
	 */
	@SuppressWarnings("unchecked")
	public CustomFilter module(String value) {
		this.module = value;
		return (CustomFilter) this;
	}

	/**
	 * Filter parameters
	 */
	@ModelNodeBinding(detypedName = "parameters")
	public Map parameters() {
		return this.parameters;
	}

	/**
	 * Filter parameters
	 */
	@SuppressWarnings("unchecked")
	public CustomFilter parameters(Map value) {
		this.parameters = value;
		return (CustomFilter) this;
	}

	/**
	 * Filter parameters
	 */
	public CustomFilter parametersEntry(String key, Object value) {
		this.parameters.put(key, value);
		return (CustomFilter) this;
	}
}

==> config-api-0.3.12-sources.jar: org/wildfly/swarm/config/undertow/configuration/CustomFilter.java <==
package org.wildfly.swarm.config.undertow.configuration;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * Custom filter
 */
@ResourceType("custom-filter")
public class CustomFilter<T extends CustomFilter> {

	private String key;
	private String className;
	private String module;
	private Map parameters;

	public CustomFilter(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Class name of HttpHandler
	 */
	@ModelNodeBinding(detypedName = "class-name")
	public String className() {
		return this.className;
	}

	/**
	 * Class name of HttpHandler
	 */
	@SuppressWarnings("unchecked")
	public T className(String value) {
		this.className = value;
		return (T) this;
	}

	/**
	 * Module name where class can be loaded from
	 */
	@ModelNodeBinding(detypedName = "module")
	public String module() {
		return this.module;
	}

	/**
	 * Module name where class can be loaded from
	 */
	@SuppressWarnings("unchecked")
	public T module(String value) {
		this.module = value;
		return (T) this;
	}

	/**
	 * Filter parameters
	 */
	@ModelNodeBinding(detypedName = "parameters")
	public Map parameters() {
		return this.parameters;
	}

	/**
	 * Filter parameters
	 */
	@SuppressWarnings("unchecked")
	public T parameters(Map value) {
		this.parameters = value;
		return (T) this;
	}

	/**
	 * Filter parameters
	 */
	public T parameter(String key, Object value) {
		if (this.parameters == null) {
			this.parameters = new java.util.HashMap<>();
		}
		this.parameters.put(key, value);
		return (T) this;
	}
}
